==> syslog-ng-3.33.2.tar.gz: syslog-ng-3.33.2/modules/mqtt/mqtt-parser.c <==
/*
 * Copyright (c) 2021 One Identity
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 as published
 * by the Free Software Foundation, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * As an additional exemption you are allowed to compile & link against the
 * OpenSSL libraries as published by the OpenSSL project. See the file
 * COPYING for details.
 *
 */

#include "driver.h"
#include "cfg-parser.h"
#include "mqtt-grammar.h"


extern int mqtt_destination_debug;

int mqtt_destination_parse(CfgLexer *lexer, LogDriver **instance, gpointer arg);

static CfgLexerKeyword mqtt_destination_keywords[] =
{
  { "mqtt", KW_MQTT },
  { "address", KW_ADDRESS },
  { "topic", KW_TOPIC },
  { "fallback_topic", KW_FALLBACK_TOPIC },
  { "keepalive", KW_KEEPALIVE },
  { "qos", KW_QOS },
  { NULL }
};

CfgParser mqtt_destination_parser =
{
#if SYSLOG_NG_ENABLE_DEBUG
  .debug_flag = &mqtt_destination_debug,
#endif
  .name = "mqtt_destination",
  .keywords = mqtt_destination_keywords,
  .parse = (gint (*)(CfgLexer *, gpointer *, gpointer)) mqtt_destination_parse,
  .cleanup = (void (*)(gpointer)) log_pipe_unref,
};

CFG_PARSER_IMPLEMENT_LEXER_BINDING(mqtt_destination_, MQTT_DESTINATION_, LogDriver **)

==> syslog-ng-3.34.1.tar.gz: syslog-ng-3.34.1/modules/mqtt/mqtt-parser.c <==
/*
 * Copyright (c) 2021 One Identity
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 as published
 * by the Free Software Foundation, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * As an additional exemption you are allowed to compile & link against the
 * OpenSSL libraries as published by the OpenSSL project. See the file
 * COPYING for details.
 *
 */

#include "driver.h"
#include "cfg-parser.h"
#include "mqtt-grammar.h"


extern int mqtt_destination_debug;

int mqtt_destination_parse(CfgLexer *lexer, LogDriver **instance, gpointer arg);

static CfgLexerKeyword mqtt_destination_keywords[] =
{
  { "mqtt", KW_MQTT },
  { "address", KW_ADDRESS },
  { "topic", KW_TOPIC },
  { "fallback_topic", KW_FALLBACK_TOPIC },
  { "keepalive", KW_KEEPALIVE },
  { "qos", KW_QOS },
  { "username", KW_USERNAME },
  { "password", KW_PASSWORD },
  { "http_proxy", KW_HTTP_PROXY },
  { "tls", KW_TLS },
  { "ca_dir", KW_CA_DIR },
  { "ca_file", KW_CA_FILE },
  { "cert_file", KW_CERT_FILE },
  { "key_file", KW_KEY_FILE },
  { "cipher_suite", KW_CIPHER_SUITE },
  { "peer_verify", KW_PEER_VERIFY },
  { "use_system_cert_store", KW_USE_SYSTEM_CERT_STORE },
  { "ssl_version", KW_SSL_VERSION },
  { NULL }
};

CfgParser mqtt_destination_parser =
{
#if SYSLOG_NG_ENABLE_DEBUG
  .debug_flag = &mqtt_destination_debug,
#endif
  .name = "mqtt_destination",
  .keywords = mqtt_destination_keywords,
  .parse = (gint (*)(CfgLexer *, gpointer *, gpointer)) mqtt_destination_parse,
  .cleanup = (void (*)(gpointer)) log_pipe_unref,
};

CFG_PARSER_IMPLEMENT_LEXER_BINDING(mqtt_destination_, MQTT_DESTINATION_, LogDriver **)
